.. _api:

API Documentation
=================

Glances provides an `XML-RPC server`_ and a `RESTful-JSON`_ API which
can be used by other clients.

API documentation is available at:

- XML-RPC: https://github.com/nicolargo/glances/wiki/The-Glances-2.x-API-How-to
- RESTful-JSON: https://github.com/nicolargo/glances/wiki/The-Glances-RESTFULL-JSON-API

.. _XML-RPC server: http://docs.python.org/2/library/simplexmlrpcserver.html
.. _RESTful-JSON: http://jsonapi.org/
